@@ -1,5 +1,5 @@
 /*
- * Copyright © 2020-2021 The Crust Firmware Authors.
+ * Copyright © 2020-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -18,11 +18,11 @@ void
 debug_print_latency(uint8_t current_state)
 {
 	if (current_state != last_state) {
-		cycles     = counter_read();
+		cycles     = cycle_counter_read();
 		iterations = 0;
 		last_state = current_state;
 	} else if (iterations < ITERATIONS && ++iterations == ITERATIONS) {
 		info("State %u: %u cycles/iteration", current_state,
-		     udiv_round(counter_read() - cycles, ITERATIONS));
+		     udiv_round(cycle_counter_read() - cycles, ITERATIONS));
 	}
 }
