@@ -1,5 +1,5 @@
 /*
- * Copyright © 2017-2021 The Crust Firmware Authors.
+ * Copyright © 2017-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -27,7 +27,6 @@
 #include <clock/ccu.h>
 #include <gpio/sunxi-gpio.h>
 #include <msgbox/sunxi-msgbox.h>
-#include <watchdog/sunxi-twd.h>
 
 #define NEXT_STATE (system_state + 2)
 
@@ -106,10 +105,10 @@ system_state_machine(uint32_t exception)
 		system_state = SS_AWAKE;
 
 		/* First, enable watchdog protection. */
-		watchdog = device_get_or_null(&r_twd.dev);
+		watchdog = watchdog_get();
 
 		/* Perform one-time device driver initialization. */
-		counter_init();
+		cycle_counter_init();
 		r_ccu_init();
 		ccu_init();
 		css_init();
@@ -126,9 +125,9 @@ system_state_machine(uint32_t exception)
 	 * could result in a silent infinite loop.
 	 *
 	 * Serial communication needs accurate clock frequencies. Specifically,
-	 * OSC16M must be calibrated before initializing R_UART, and R_UART
+	 * IOSC must be calibrated before initializing R_UART, and R_UART
 	 * will only work after an exception restart while off/asleep if the
-	 * calibrated OSC16M frequency is retained across the restart.
+	 * calibrated IOSC frequency is retained across the restart.
 	 */
 	serial_init();
 
@@ -270,7 +269,7 @@ system_state_machine(uint32_t exception)
 			r_ccu_resume();
 
 			/* Enable watchdog protection. */
-			watchdog = device_get_or_null(&r_twd.dev);
+			watchdog = watchdog_get();
 
 			/* The system is now ready to reset or resume. */
 			system_state = NEXT_STATE;
@@ -294,6 +293,7 @@ system_state_machine(uint32_t exception)
 			mailbox = device_get_or_null(&msgbox.dev);
 
 			/* Resume execution on the CSS. */
+			record_step(STEP_RESUME_CSS);
 			css_resume();
 
 			record_step(STEP_RESUME_COMPLETE);
@@ -314,7 +314,7 @@ system_state_machine(uint32_t exception)
 		case SS_RESET:
 			/* Attempt to reset the SoC using the watchdog. */
 			if (watchdog)
-				watchdog_set_timeout(watchdog, 1);
+				watchdog_reset_system(watchdog);
 
 			/* Continue making reboot/reset attempts. */
 			break;
