@@ -1,5 +1,5 @@
 /*
- * Copyright © 2017-2021 The Crust Firmware Authors.
+ * Copyright © 2017-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -11,7 +11,7 @@
 bool
 timeout_expired(uint32_t timeout)
 {
-	uint32_t now = counter_read();
+	uint32_t now = cycle_counter_read();
 
 	/* If the timeout wrapped, wait until the counter also wraps. */
 	return (now ^ timeout) >> 31 == 0 && now >= timeout;
@@ -21,7 +21,7 @@ uint32_t
 timeout_set(uint32_t useconds)
 {
 	uint32_t cycles = CPUCLK_MHz * useconds;
-	uint32_t now    = counter_read();
+	uint32_t now    = cycle_counter_read();
 
 	/* Ensure the MSB is zero for the wraparound check above. */
 	assert(cycles >> 31 == 0);
