@@ -1,5 +1,5 @@
 /*
- * Copyright © 2019-2021 The Crust Firmware Authors.
+ * Copyright © 2019-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -8,7 +8,6 @@
 #include <mmio.h>
 #include <stdint.h>
 #include <system.h>
-#include <watchdog/sunxi-twd.h>
 #include <platform/devices.h>
 #include <platform/prcm.h>
 #include <platform/time.h>
@@ -20,9 +19,9 @@
 	                    PLL_CTRL_REG1_LDO_EN)
 
 /* Persist this var as r_ccu_init() may not be called after an exception. */
-static uint32_t osc16m_rate = 16000000U;
+static uint32_t iosc_rate = CPUCLK_Hz;
 
-DEFINE_FIXED_RATE(r_ccu_common_get_osc16m_rate, osc16m_rate)
+DEFINE_FIXED_RATE(r_ccu_common_get_iosc_rate, iosc_rate)
 
 /**
  * Write a value to the lockable bits in PLL_CTRL_REG1.
@@ -95,24 +94,24 @@ r_ccu_common_init(void)
 
 	/* Cycle until the interval will not span a counter wraparound. */
 	do {
-		before = counter_read();
+		before = cycle_counter_read();
 		barrier();
-		now = r_twd_counter_read();
+		now = system_counter_read();
 		end = now + (REFCLK_HZ >> 9);
 	} while (end < now);
 
 	/* Cycle until the end of the interval. */
 	do {
-		after = counter_read();
+		after = cycle_counter_read();
 		/* Ensure the counters are read in a consistent order. */
 		barrier();
-		now = r_twd_counter_read();
+		now = system_counter_read();
 	} while (now < end);
 
 	/*
-	 * Convert the number of OSC16M cycles in 1/512 second to Hz. 512 is
+	 * Convert the number of IOSC cycles in 1/512 second to Hz. 512 is
 	 * chosen because it is the largest power-of-two factor of 24MHz, the
 	 * reference clock frequency.
 	 */
-	osc16m_rate = (after - before) << 9;
+	iosc_rate = (after - before) << 9;
 }
