@@ -1,5 +1,5 @@
 /*
- * Copyright © 2017-2021 The Crust Firmware Authors.
+ * Copyright © 2017-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -14,7 +14,11 @@
 #define IC_TYPE_REG   0x03
 #define IC_TYPE_MASK  0xcf
 
-#if CONFIG(MFD_AXP803)
+#if CONFIG(MFD_AXP223)
+#define IC_TYPE_VALUE 0x06
+#define I2C_ADDRESS   0x34
+#define RSB_ADDRESS   (0x2d << 16 | 0x3a3)
+#elif CONFIG(MFD_AXP803)
 #define IC_TYPE_VALUE 0x41
 #define I2C_ADDRESS   0x34
 #define RSB_ADDRESS   (0x2d << 16 | 0x3a3)
