@@ -1,11 +1,12 @@
 /*
- * Copyright © 2017-2021 The Crust Firmware Authors.
+ * Copyright © 2017-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
 #include <device.h>
 #include <intrusive.h>
 #include <pmic.h>
+#include <pmic/axp223.h>
 #include <pmic/axp803.h>
 #include <pmic/axp805.h>
 
@@ -28,9 +29,11 @@ pmic_get(void)
 {
 	const struct device *pmic = NULL;
 
+	if (CONFIG(PMIC_AXP223))
+		pmic = device_get_or_null(&axp223_pmic.dev);
 	if (CONFIG(PMIC_AXP803))
 		pmic = device_get_or_null(&axp803_pmic.dev);
-	if (!pmic && CONFIG(PMIC_AXP805))
+	if (CONFIG(PMIC_AXP805))
 		pmic = device_get_or_null(&axp805_pmic.dev);
 
 	return pmic;
