@@ -1,5 +1,5 @@
 /*
- * Copyright © 2017-2021 The Crust Firmware Authors.
+ * Copyright © 2017-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -15,8 +15,6 @@
 struct axp20x_regulator_info {
 	uint8_t enable_register;
 	uint8_t enable_mask;
-	uint8_t value_register;
-	uint8_t value_mask;
 };
 
 extern const struct regulator_driver axp20x_regulator_driver;
