@@ -1,5 +1,5 @@
 /*
- * Copyright © 2017-2021 The Crust Firmware Authors.
+ * Copyright © 2017-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -7,6 +7,8 @@
 #include <intrusive.h>
 #include <stdint.h>
 #include <watchdog.h>
+#include <watchdog/sun6i-a31-wdt.h>
+#include <watchdog/sun9i-a80-twd.h>
 
 #include "watchdog.h"
 
@@ -22,14 +24,27 @@ watchdog_ops_for(const struct device *dev)
 	return &drv->ops;
 }
 
+const struct device *
+watchdog_get(void)
+{
+	const struct device *watchdog = NULL;
+
+	if (CONFIG(WATCHDOG_SUN6I_A31_WDT))
+		watchdog = device_get_or_null(&r_wdog.dev);
+	if (CONFIG(WATCHDOG_SUN9I_A80_TWD))
+		watchdog = device_get_or_null(&r_twd.dev);
+
+	return watchdog;
+}
+
+void
+watchdog_reset_system(const struct device *dev)
+{
+	watchdog_ops_for(dev)->reset_system(dev);
+}
+
 void
 watchdog_restart(const struct device *dev)
 {
 	watchdog_ops_for(dev)->restart(dev);
 }
-
-void
-watchdog_set_timeout(const struct device *dev, uint32_t timeout)
-{
-	watchdog_ops_for(dev)->set_timeout(dev, timeout);
-}
