@@ -1,5 +1,5 @@
 /*
- * Copyright © 2017-2021 The Crust Firmware Authors.
+ * Copyright © 2017-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -10,8 +10,8 @@
 #include <stdint.h>
 
 struct watchdog_driver_ops {
+	void (*reset_system)(const struct device *dev);
 	void (*restart)(const struct device *dev);
-	void (*set_timeout)(const struct device *dev, uint32_t timeout);
 };
 
 struct watchdog_driver {
