@@ -1,5 +1,5 @@
 /*
- * Copyright © 2021 The Crust Firmware Authors.
+ * Copyright © 2021-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -33,8 +33,6 @@ enum {
 	STEP_RESUME_DRAM_CHECKSUM,
 	STEP_RESUME_DEVICES,
 	STEP_RESUME_CSS,
-	STEP_RESUME_CLUSTER,
-	STEP_RESUME_CORE,
 	STEP_RESUME_COMPLETE,
 };
 
