@@ -1,5 +1,5 @@
 /*
- * Copyright © 2017-2021 The Crust Firmware Authors.
+ * Copyright © 2017-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -7,7 +7,7 @@
 #define DRIVERS_CLOCK_SUN50I_H6_R_CCU_H
 
 enum {
-	CLK_OSC16M,
+	CLK_IOSC,
 	CLK_OSC24M,
 	CLK_OSC32K,
 	CLK_AR100,
