@@ -1,5 +1,5 @@
 /*
- * Copyright © 2017-2021 The Crust Firmware Authors.
+ * Copyright © 2017-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -8,6 +8,20 @@
 
 #include <device.h>
 
+/**
+ * Get a reference to an available watchdog device.
+ *
+ * @return A reference to a watchdog device.
+ */
+const struct device *watchdog_get(void);
+
+/**
+ * Use the watchdog to reset the system as soon as possible.
+ *
+ * @param dev The watchdog device.
+ */
+void watchdog_reset_system(const struct device *dev);
+
 /**
  * Restart the watchdog. This must be called before the watchdog times out.
  *
@@ -15,12 +29,4 @@
  */
 void watchdog_restart(const struct device *dev);
 
-/**
- * Set the watchdog timeout. It will take effect after the next restart.
- *
- * @param dev     The watchdog device.
- * @param timeout The new watchdog timeout in clock cycles.
- */
-void watchdog_set_timeout(const struct device *dev, uint32_t timeout);
-
 #endif /* DRIVERS_WATCHDOG_H */
