@@ -1,5 +1,5 @@
 /*
- * Copyright © 2020-2021 The Crust Firmware Authors.
+ * Copyright © 2020-2022 The Crust Firmware Authors.
  * SPDX-License-Identifier: BSD-3-Clause OR GPL-2.0-only
  */
 
@@ -61,4 +61,11 @@
 #define DBG_CTRL_REG1_DBGPWRDUP(n)       BIT(0 + (n))
 #define DBG_CTRL_REG1_DBGPWRDUP_MASK     (0xf << 0)
 
+#define CNT64_CTRL_REG                   (DEV_R_CPUCFG + 0x0280)
+#define CNT64_RL_EN                      BIT(1)
+#define CNT64_CLR_EN                     BIT(0)
+
+#define CNT64_LO_REG                     (DEV_R_CPUCFG + 0x0284)
+#define CNT64_HI_REG                     (DEV_R_CPUCFG + 0x0288)
+
 #endif /* PLATFORM_CPUCFG_H */
